@@ -1,7 +1,7 @@
 package WWW::Chain::UA;
 our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Role for classes which have a request_chain function for a WWW::Chain object
-$WWW::Chain::UA::VERSION = '0.006';
+$WWW::Chain::UA::VERSION = '0.007';
 use Moo::Role;
 
 requires qw( request_chain );
@@ -18,15 +18,15 @@ WWW::Chain::UA - Role for classes which have a request_chain function for a WWW:
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 AUTHOR
 
-Torsten Raudssus <torsten@raudss.us>
+Torsten Raudssus <torsten@raudssus.de> L<https://raudss.us/>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Torsten Raudssus.
+This software is copyright (c) 2024 by Torsten Raudssus.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
